@@ -19,3 +19,9 @@ print.token = function(x, reveal = FALSE, ...) {
     cat("<hidden token>")
   }
 }
+
+#' @export
+#' @rdname print.token
+reveal = function(x, ...) {
+  print(x, reveal = TRUE, ...)
+}
